@@ -1,13 +1,24 @@
+"""Main package."""
 import pytest
 import pkg_resources
 import micromagnetictests.calculatortests
 from .get_tests import get_tests
 
-
-def test():
-    return pytest.main(['-v', '--pyargs',
-                        'micromagnetictests'])  # pragma: no cover
-
-
 __version__ = pkg_resources.get_distribution(__name__).version
 __dependencies__ = pkg_resources.require(__name__)
+
+
+def test():
+    """Run all package tests.
+
+    Examples
+    --------
+    1. Run all tests.
+
+    >>> import micromagnetictests as mt
+    ...
+    >>> # mt.test()
+
+    """
+    return pytest.main(['-v', '--pyargs',
+                        'micromagnetictests', '-l'])  # pragma: no cover
