@@ -1,3 +1,4 @@
+"""Calculator tests"""
 from .exchange import TestExchange
 from .dmi import TestDMI
 from .uniaxialanisotropy import TestUniaxialAnisotropy
@@ -13,10 +14,15 @@ from .slonczewski import TestSlonczewski
 from .dynamics import TestDynamics
 from .mindriver import TestMinDriver
 from .timedriver import TestTimeDriver
+from .hysteresisdriver import TestHysteresisDriver
 from .mesh import TestMesh
 from .compute import TestCompute
 from .info_file import test_info_file
 from .multiple_drives import test_multiple_drives
+from .fixedsubregions import TestFixedSubregions
+from .outputstep import test_outputstep
+from .threads import TestThreads
+from .dirname import test_dirname
 from .stdprob3 import test_stdprob3
 from .stdprob4 import test_stdprob4
 from .stdprob5 import test_stdprob5
